==> rollup-plugin-sizes-0.1.0.tgz: package/README.md <==
rollup-plugin-sizes [![NPM Version](https://img.shields.io/npm/v/rollup-plugin-sizes.svg)](https://www.npmjs.com/package/rollup-plugin-sizes) [![Build Status](https://img.shields.io/travis/tivac/rollup-plugin-sizes/master.svg)](https://travis-ci.org/tivac/rollup-plugin-sizes)
===========
<p align="center">
    <a href="https://www.npmjs.com/package/rollup-plugin-sizes" alt="NPM License"><img src="https://img.shields.io/npm/l/rollup-plugin-sizes.svg" /></a>
    <a href="https://www.npmjs.com/package/rollup-plugin-sizes" alt="NPM Downloads"><img src="https://img.shields.io/npm/dm/rollup-plugin-sizes.svg" /></a>
    <a href="https://david-dm.org/tivac/rollup-plugin-sizes" alt="Dependency Status"><img src="https://img.shields.io/david/tivac/rollup-plugin-sizes.svg" /></a>
    <a href="https://david-dm.org/tivac/rollup-plugin-sizes#info=devDependencies" alt="devDependency Status"><img src="https://img.shields.io/david/dev/tivac/rollup-plugin-sizes.svg" /></a>
</p>

Simple analysis on rollup bundling, helping you to spot libaries bloating up your bundles.

```
Bundle Contents:
codemirror - 445.33 KB (33.68%)
remarkable - 189.54 KB (14.33%)
lodash._baseiteratee - 112.48 KB (8.51%)
app - 93.59 KB (7.08%)
autolinker - 81.63 KB (6.17%)
...
```

## Install

`$ npm i rollup-plugin-sizes -D`

## Usage

Add to your rollup build as the last plugin via JS API or Config file.

### JS API

```js
var rollup = require("rollup"),
    
    buble = require("rollup-plugin-buble"),
    sizes = require("rollup-plugin-sizes");

rollup.rollup({
    entry   : "src/main.js",
    plugins : [
        buble(),
        sizes()
    ]
}).then(function(bundle) {
    ...
});
```

## Config file

```js
import buble from 'rollup-plugin-buble';
import sizes from 'rollup-plugin-sizes';

export default {
    ...
    plugins : [
        buble(),
        sizes()
    ]
};
```
## A Note on Versioning ##

This project's version number currently has a "0.x" prefix, indicating that it's a young
project under heavy development. **As long as the version number starts with
"0.x", minor revisions may introduce breaking changes.**

You've been warned!

Once it reaches version 1.0.0, it will adhere strictly to [SemVer 2.0](http://semver.org/spec/v2.0.0.html).

==> rollup-plugin-sizes-0.2.3.tgz: package/README.md <==
rollup-plugin-sizes [![NPM Version](https://img.shields.io/npm/v/rollup-plugin-sizes.svg)](https://www.npmjs.com/package/rollup-plugin-sizes) [![Build Status](https://img.shields.io/travis/tivac/rollup-plugin-sizes/master.svg)](https://travis-ci.org/tivac/rollup-plugin-sizes)
===========
<p align="center">
    <a href="https://www.npmjs.com/package/rollup-plugin-sizes" alt="NPM License"><img src="https://img.shields.io/npm/l/rollup-plugin-sizes.svg" /></a>
    <a href="https://www.npmjs.com/package/rollup-plugin-sizes" alt="NPM Downloads"><img src="https://img.shields.io/npm/dm/rollup-plugin-sizes.svg" /></a>
    <a href="https://david-dm.org/tivac/rollup-plugin-sizes" alt="Dependency Status"><img src="https://img.shields.io/david/tivac/rollup-plugin-sizes.svg" /></a>
    <a href="https://david-dm.org/tivac/rollup-plugin-sizes#info=devDependencies" alt="devDependency Status"><img src="https://img.shields.io/david/dev/tivac/rollup-plugin-sizes.svg" /></a>
</p>

Simple analysis on rollup bundling, helping you to spot libaries bloating up your bundles.

```
/src/index.js:
codemirror - 446.92 KB (35.94%)
remarkable - 193.72 KB (15.58%)
app - 95.87 KB (7.71%)
autolinker - 81.64 KB (6.57%)
lodash.filter - 62.77 KB (5.05%)
...
```

or with way more details!

```
/src/index.js:
codemirror - 446.92 KB (35.94%)
        lib\codemirror.js - 347.8 KB (77.82%)
        mode\javascript\javascript.js - 27.78 KB (6.22%)
        mode\markdown\markdown.js - 25.54 KB (5.72%)
        mode\meta.js - 14.44 KB (3.23%)
        mode\xml\xml.js - 12.52 KB (2.80%)
        addon\edit\closebrackets.js - 7.04 KB (1.58%)
        addon\edit\matchbrackets.js - 5.39 KB (1.21%)
        addon\comment\continuecomment.js - 3.59 KB (0.80%)
        addon\selection\active-line.js - 2.82 KB (0.63%)
remarkable - 193.72 KB (15.58%)
        lib\common\entities.js - 46.44 KB (23.97%)
        lib\rules.js - 10.2 KB (5.26%)
        lib\rules_block\list.js - 6.65 KB (3.43%)
        lib\ruler.js - 5.44 KB (2.81%)
        lib\rules_block\deflist.js - 5.22 KB (2.69%)
...
```

## Install

`$ npm i rollup-plugin-sizes -D`

## Usage

Add to your rollup build as the last plugin via JS API or Config file.

### JS API

```js
var rollup = require("rollup"),
    
    buble = require("rollup-plugin-buble"),
    sizes = require("rollup-plugin-sizes");

rollup.rollup({
    entry   : "src/main.js",
    plugins : [
        buble(),
        sizes()
    ]
}).then(function(bundle) {
    ...
});
```

## Config file

```js
import buble from 'rollup-plugin-buble';
import sizes from 'rollup-plugin-sizes';

export default {
    ...
    plugins : [
        buble(),
        sizes()
    ]
};
```

## Options

`details` - Set to true to enable file-by-file breakdowns of space usage.

## A Note on Versioning

This project's version number currently has a "0.x" prefix, indicating that it's a young
project under heavy development. **As long as the version number starts with
"0.x", minor revisions may introduce breaking changes.**

You've been warned!

Once it reaches version 1.0.0, it will adhere strictly to [SemVer 2.0](http://semver.org/spec/v2.0.0.html).
